==> jc-1.4.0.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24LocatorAdapter.h <==
// class gnu.xml.util.SAXNullTransformerFactory$LocatorAdapter

// class file dependencies
// @dep_class 1dc6ae81e96e52e9 gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b459788dc8d17cb0 org_xml_sax_helpers_LocatorImpl

// header file dependencies
// @dep_header org_xml_sax_helpers_LocatorImpl

#include "org/xml/sax/helpers/LocatorImpl.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$method$_init$a8751dacb6eb8f2c(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_LocatorImpl$vmethods	org_xml_sax_helpers_LocatorImpl;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods	gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_refs	org_xml_sax_helpers_LocatorImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_nonrefs	org_xml_sax_helpers_LocatorImpl;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24LocatorAdapter.h <==
// class gnu.xml.util.SAXNullTransformerFactory$LocatorAdapter

// class file dependencies
// @dep_class 1dc6ae81e96e52e9 gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b459788dc8d17cb0 org_xml_sax_helpers_LocatorImpl

// header file dependencies
// @dep_header org_xml_sax_helpers_LocatorImpl

#include "org/xml/sax/helpers/LocatorImpl.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$method$_init$a8751dacb6eb8f2c(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_LocatorImpl$vmethods	org_xml_sax_helpers_LocatorImpl;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vmethods	gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_refs	org_xml_sax_helpers_LocatorImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_nonrefs	org_xml_sax_helpers_LocatorImpl;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24LocatorAdapter_H_ */
